summaryrefslogtreecommitdiff
path: root/java/com/android/dialer/phonelookup/phone_lookup_info.proto
diff options
context:
space:
mode:
Diffstat (limited to 'java/com/android/dialer/phonelookup/phone_lookup_info.proto')
-rw-r--r--java/com/android/dialer/phonelookup/phone_lookup_info.proto49
1 files changed, 39 insertions, 10 deletions
diff --git a/java/com/android/dialer/phonelookup/phone_lookup_info.proto b/java/com/android/dialer/phonelookup/phone_lookup_info.proto
index f1497bdca..b5e73ccbe 100644
--- a/java/com/android/dialer/phonelookup/phone_lookup_info.proto
+++ b/java/com/android/dialer/phonelookup/phone_lookup_info.proto
@@ -13,29 +13,51 @@ package com.android.dialer.phonelookup;
// to an implementation of PhoneLookup. For example, field "cp2_local_info"
// corresponds to class Cp2LocalPhoneLookup, and class Cp2LocalPhoneLookup
// alone is responsible for populating it.
+// Next ID: 7
message PhoneLookupInfo {
- // Information about a PhoneNumber retrieved from CP2. Cp2LocalPhoneLookup is
- // responsible for populating the data in this message.
+ // Information about a PhoneNumber retrieved from CP2.
message Cp2Info {
// Information about a single local contact.
message Cp2ContactInfo {
- // android.provider.ContactsContract.CommonDataKinds.Phone.DISPLAY_NAME_PRIMARY
+ // For a local contact:
+ // android.provider.ContactsContract.CommonDataKinds.Phone.DISPLAY_NAME_PRIMARY
+ // For a remote contact:
+ // android.provider.ContactsContract.PhoneLookup.DISPLAY_NAME_PRIMARY
optional string name = 1;
- // android.provider.ContactsContract.CommonDataKinds.Phone.PHOTO_THUMBNAIL_URI
+ // For a local contact:
+ // android.provider.ContactsContract.CommonDataKinds.Phone.PHOTO_THUMBNAIL_URI
+ // For a remote contact:
+ // android.provider.ContactsContract.PhoneLookup.PHOTO_THUMBNAIL_URI
optional string photo_uri = 2;
- // android.provider.ContactsContract.CommonDataKinds.Phone.PHOTO_ID
+ // For a local contact:
+ // android.provider.ContactsContract.CommonDataKinds.Phone.PHOTO_ID
+ // For a remote contact:
+ // android.provider.ContactsContract.PhoneLookup.PHOTO_ID
optional fixed64 photo_id = 3;
- // android.provider.ContactsContract.CommonDataKinds.Phone.LABEL
- // "Home", "Mobile", ect.
+ // For a local contact:
+ // android.provider.ContactsContract.CommonDataKinds.Phone.LABEL
+ // For a remote contact:
+ // android.provider.ContactsContract.PhoneLookup.LABEL
+ //
+ // The value can be "Home", "Mobile", ect.
optional string label = 4;
- // android.provider.ContactsContract.CommonDataKinds.Phone.CONTACT_ID
+ // For a local contact:
+ // android.provider.ContactsContract.CommonDataKinds.Phone.CONTACT_ID
+ // For a remote contact:
+ // android.provider.ContactsContract.PhoneLookup.CONTACT_ID
optional fixed64 contact_id = 5;
- // android.provider.ContactsContract.CONTENT_LOOKUP_URI
+ // For a local contact:
+ // constructed based on
+ // android.provider.ContactsContract.CommonDataKinds.Phone.LOOKUP_KEY
+ // For a remote contact:
+ // constructed based on
+ // android.provider.ContactsContract.PhoneLookup.LOOKUP_KEY
optional string lookup_uri = 6;
}
// Repeated because one phone number can be associated with multiple CP2
@@ -50,8 +72,15 @@ message PhoneLookupInfo {
// log needs to query for the CP2 information at render time.
optional bool is_incomplete = 2;
}
+
+ // Information about a local contact retrieved via CP2.
+ // Cp2LocalPhoneLookup is responsible for populating this field.
optional Cp2Info cp2_local_info = 1;
+ // Information about a remote contact retrieved via CP2.
+ // Cp2RemotePhoneLookup is responsible for populating this field.
+ optional Cp2Info cp2_remote_info = 6;
+
// Message for APDL, a lookup for the proprietary Google dialer.
message ApdlInfo {
optional bool is_spam = 1;
@@ -13,29 +13,51 @@ package com.android.dialer.phonelookup;
message Cp2Info {
- // Information about a single local contact.
+ // Information about a single contact, which can be a local contact or a
+ // remote one.
message Cp2ContactInfo {